@@ -8,17 +8,9 @@ our @ISA = qw(Exporter);
 
 our @EXPORT_OK = qw(cpp2xs);
 
-our $VERSION = 0.15;
+our $VERSION = 0.16;
 
-my $config_options =
-       {
-       'AUTOWRAP' => 0,
-       'AUTO_INCLUDE' => '',
-       'LIBS' => [],
-       'VERSION' => 0,
-       'WRITE_MAKEFILE_PL' => 0,
-       'WRITE_PM' => 0,
-       };
+my $config_options;
 
 sub cpp2xs {
     ## This is basically just a copy'n'paste of the InlineX::C2XS::c2xs() function,
@@ -249,7 +241,7 @@ sub _build {
 sub _check_config_keys {
     for('AUTOWRAP', 'AUTO_INCLUDE', 'TYPEMAPS', 'LIBS', 'INC', 'VERSION', 'WRITE_MAKEFILE_PL',
         'BUILD_NOISY', 'BOOT', 'EXPORT_ALL', 'EXPORT_OK_ALL', 'EXPORT_TAGS_ALL', 'MAKE',
-        'PREFIX', 'CCFLAGS', 'LD', 'LDDLFLAGS', 'MYEXTLIB', 'OPTIMIZE', 'CC', 'USING',
+        'PREFIX', 'CCFLAGS', 'LD', 'LDDLFLAGS', 'MYEXTLIB', 'OPTIMIZE', 'CC', 'USE', 'USING',
         'WRITE_PM', 'CODE', 'SRC_LOCATION')
        {return 1 if $_ eq $_[0]} # it's a valid config option
     return 0;                    # it's an invalid config option
@@ -260,13 +252,24 @@ sub _write_pm {
     my $offset = 4;
     my $max = 100;
     my $length = $offset;
+    my @use;
+
+    if($config_options->{USE}) {
+      die "Value supplied to config option USE must be an array reference" 
+        if ref($config_options->{USE}) ne 'ARRAY';
+      @use = @{$config_options->{USE}};
+    }
 
     open(WR, '>', $o->{API}{build_dir} . '/' . $o->{API}{modfname} . ".pm")
         or die "Couldn't create the .pm file: $!";
     print "Writing ", $o->{API}{modfname}, ".pm in the ", $o->{API}{build_dir}, " directory\n";
     print WR "## This file generated by InlineX::CPP2XS (version ",
              $InlineX::CPP2XS::VERSION, ") using Inline::CPP (version ", $Inline::CPP::VERSION, ")\n";
-    print WR "package ", $o->{API}{module}, ";\nuse strict;\n\n";
+    print WR "package ", $o->{API}{module}, ";\n";
+    for(@use) {
+      print WR "use ${_};\n";
+    }
+    print WR "\n";
     print WR "require Exporter;\n*import = \\&Exporter::import;\nrequire DynaLoader;\n\n";
     print WR "\$", $o->{API}{module}, "::VERSION = '", $o->{API}{version}, "';\n\n"; 
     print WR "DynaLoader::bootstrap ", $o->{API}{module}, " \$", $o->{API}{module}, "::VERSION;\n\n";
@@ -606,6 +609,14 @@ InlineX::CPP2XS - Convert from Inline C++ code to XS.
     TYPEMAPS =>'my_typemap my_other_typemap',
   ----
 
+  USE
+   Must be an array reference, listing the modules that the autogenerated
+   pm file needs to load (use). Makes no sense to assign this key if
+   WRITE_PM is not set to a true value. eg:
+
+    USE => ['Digest::MD5', 'LWP::Simple'];
+  ----
+
   USING
     With Inline::C, enables use of an alternative parser. But with
     Inline::CPP, there is currently no alternative parser available.
@@ -651,7 +662,7 @@ InlineX::CPP2XS - Convert from Inline C++ code to XS.
 
    This program is free software; you may redistribute it and/or 
    modify it under the same terms as Perl itself.
-   Copyright 2006-2009, Sisyphus
+   Copyright 2006-2009, 2010, Sisyphus
 
 =head1 AUTHOR
 
